NailGun
=======

.. image:: https://coveralls.io/repos/SatelliteQE/nailgun/badge.svg
   :target: https://coveralls.io/r/SatelliteQE/nailgun

NailGun is a GPL-licensed Python library that facilitates easy usage of the
Satellite 6 API.

The `full documentation <http://nailgun.readthedocs.org/en/latest/>`_ is
available on ReadTheDocs. It can also be generated locally::

    pip install -r requirements.txt -r requirements-dev.txt
    make docs-html
